<?php
/*-------------------------------------------------------+
| PHPFusion Content Management System
| Copyright (C) PHP Fusion Inc
| https://phpfusion.com/
+--------------------------------------------------------+
| Filename: admin.php
| Author: karrak
+--------------------------------------------------------+
| This program is released as free software under the
| Affero GPL license. You can redistribute it and/or
| modify it under the terms of this license which you
| can read by viewing the included agpl.txt or online
| at www.gnu.org/licenses/agpl.html. Removal of this
| copyright header is strictly prohibited without
| written permission from the original author(s).
+--------------------------------------------------------*/
require_once __DIR__.'/../../maincore.php';
require_once FUSION_ADMIN_HEADER;
pageAccess("AGVF");

$locale = fusion_get_locale('', AGVF_LOCALE);
$ageverify_settings = get_settings('ageverify_panel');

add_breadcrumb(['link'  => AGVF_PATH.'admin.php'.fusion_get_aidlink(), 'title' => $locale['AGVF_020']]);
add_to_title($locale['AGVF_020']);

if (check_post("savesettings")) {
    $duration = sanitizer('ageverify_duration', 1, 'ageverify_duration');
    $inputArray = [
        'ageverify_enable'       => sanitizer('ageverify_enable', 0, 'ageverify_enable'),
        'ageverify_method'       => sanitizer('ageverify_method', 0, 'ageverify_method'),
        'ageverify_age'          => sanitizer('ageverify_age', 1000, 'ageverify_age'),
        'ageverify_duration'     => $duration * 86400,
        'ageverify_underageurl'  => sanitizer('ageverify_underageurl', '', 'ageverify_underageurl'),
        'ageverify_underagetime' => sanitizer('ageverify_underagetime', 1000, 'ageverify_underagetime')
    ];

    if (fusion_safe()) {
        foreach ($inputArray as $settings_name => $settings_value) {
            $inputSettings = [
                'settings_name'  => $settings_name,
                'settings_value' => $settings_value,
                'settings_inf'   => 'ageverify_panel'
            ];
            dbquery_insert(DB_SETTINGS_INF, $inputSettings, 'update', ['primary_key' => 'settings_name']);
        }
        addnotice('success', $locale['AGVF_021']);
    }

    redirect(FUSION_REQUEST);
}


opentable($locale['AGVF_020']);
echo openform('settingsFrm', 'POST');

echo "<div class='mb-5'><h5>".$locale['AGVF_035']."</h5></div>";
echo form_checkbox('ageverify_enable', $locale['AGVF_022'], $ageverify_settings['ageverify_enable'], [
    'inline' => TRUE,
    'toggle' => TRUE
]);

$opts = ['0' => $locale['AGVF_023'], '1' => $locale['AGVF_024'], '2' => $locale['AGVF_025']];
echo form_checkbox('ageverify_method', $locale['AGVF_026'], $ageverify_settings['ageverify_method'], [
    'options' => $opts,
    'inline'  => TRUE,
    'type'    => 'radio'
]);

echo form_text('ageverify_age', $locale['AGVF_027'], ($ageverify_settings['ageverify_age']), [
    'inline'     => TRUE,
    'type'       => 'number',
    'ext_tip'    => $locale['AGVF_028'],
    'number_min' => 1
]);

echo form_text('ageverify_duration', $locale['AGVF_029'], ($ageverify_settings['ageverify_duration']/86400), [
    'inline'     => TRUE,
    'type'       => 'number',
    'ext_tip'    => $locale['AGVF_030'],
    'number_min' => 1
]);

echo form_text('ageverify_underageurl', $locale['AGVF_031'], $ageverify_settings['ageverify_underageurl'], [
    'inline'      => TRUE,
    'type'        => 'url',
    'regex'       => 'http(s)?\:\/\/(.*?)',
    'placeholder' => $locale['AGVF_032'],
    'ext_tip'     => $locale['AGVF_032']
]);

echo form_text('ageverify_underagetime', $locale['AGVF_033'], ($ageverify_settings['ageverify_underagetime']), [
    'inline'     => TRUE,
    'type'       => 'number',
    'number_min' => 1,
    'ext_tip'    => $locale['AGVF_034']
]);

echo form_button('savesettings', $locale['save'], $locale['save'], ['class' => 'btn-success']);
echo closeform();
closetable();

require_once FUSION_FOOTER;
