<?php
/*-------------------------------------------------------+
| PHPFusion Content Management System
| Copyright (C) PHP Fusion Inc
| https://phpfusion.com/
+--------------------------------------------------------+
| Filename: ageverify_panel.php
| Author: karrak
+--------------------------------------------------------+
| This program is released as free software under the
| Affero GPL license. You can redistribute it and/or
| modify it under the terms of this license which you
| can read by viewing the included agpl.txt or online
| at www.gnu.org/licenses/agpl.html. Removal of this
| copyright header is strictly prohibited without
| written permission from the original author(s).
+--------------------------------------------------------*/
defined('IN_FUSION') || exit;

if (defined('AGEVERIFY_PANEL_EXISTS')) {
    $ageverify_settings = get_settings('ageverify_panel');
    $locale = fusion_get_locale('', AGVF_LOCALE);

    $agecookie = !isset($_COOKIE[COOKIE_PREFIX.'ageverifycontrol']) ? FALSE : TRUE;
    $text = '';
    $agebutton = '';

    if (empty($ageverify_settings['ageverify_method'])) {
        //buton
        if (check_post('yes_ageverify')) {
            set_ageVerify($ageverify_settings['ageverify_duration']);
            $agecookie = TRUE;
        }
        if (check_post('no_ageverify')) {
            $text = sprintf($locale['AGVF_010'], $ageverify_settings['ageverify_age']);
            if (!empty($ageverify_settings['ageverify_underageurl'])) {
                get_noverify($ageverify_settings['ageverify_underageurl'], $ageverify_settings['ageverify_underagetime']);
                $text .= "<br />".sprintf($locale['AGVF_011'], $ageverify_settings['ageverify_underageurl']);
            }
            $agecookie = FALSE;
        } else {
            $agebutton .= form_button('yes_ageverify', $locale['AGVF_012'], $locale['AGVF_012'], ['class'=>'btn-sc btn-sm m-l-10']);
            $agebutton .= form_button('no_ageverify', $locale['AGVF_013'], $locale['AGVF_013'], ['class'=>'btn-dg btn-sm']);
        }
    } else {
        //date
        if (check_post('ageverify_date')) {
            $agedate = sanitizer('date_ageverify', '', 'date_ageverify');
            $datestart = ($ageverify_settings['ageverify_underageurl'] == 1 ? date("Y")."-".date("m")."-".date("d") : date("Y")."-".date("d")."-".date("m"));
            $startdate = date_create($datestart);
            $enddate = date_create($agedate);
            $diff = date_diff($startdate, $enddate);
            $uyear = $diff->format("%y");

            if ($uyear >= $ageverify_settings['ageverify_age']) {
            	set_ageVerify($ageverify_settings['ageverify_duration']);
                $agecookie = TRUE;
            } else {
                $text = sprintf($locale['AGVF_010'], $ageverify_settings['ageverify_age']);
                get_noverify($ageverify_settings['ageverify_underageurl'], $ageverify_settings['ageverify_underagetime']);

                $text .= "<br />".sprintf($locale['AGVF_011'], $ageverify_settings['ageverify_underageurl']);
                $agecookie = FALSE;
            }
        } else {
            $options = [
                'inline'          => TRUE,
                'type'            => 'date',
                'width'           => '250px',
                'showTime'        => FALSE,
                'date_format_js'  => ($ageverify_settings['ageverify_underageurl'] == 1 ? 'YYYY-M-DD' : 'YYYY-DD-M'),
                'date_format_php' => ($ageverify_settings['ageverify_underageurl'] == 1 ? 'Y-m-d' : 'Y-d-m')
            ];

            $agebutton .= "<div class='m-t-10 text-center'>".form_datepicker('date_ageverify', ' ', '', $options)."</div>";
            $agebutton .= "<div class='text-center'>".$locale['AGVF_014']."</div>";
            $agebutton .= form_button('ageverify_date', $locale['submit'], $locale['submit'], ['class'=>'btn-dg btn-sm']);
        }
    }

    if (!empty($ageverify_settings['ageverify_enable']) && $agecookie == FALSE) {
        $footer = openmodal('ageverify_preview', '', ['static' => TRUE]);
        $footer .= "<div class='row'>\n";
        $footer .= "<div class='agediv'>\n";
        if (!empty($text)) {
            $footer .= "<div class='col-xs-12 col-md-12 m-t-10'>\n";
            $footer .= "<div class='well text-center text-danger'>".parse_text($text, [
                'parse_smileys'        => FALSE,
                'parse_bbcode'         => FALSE,
                'default_image_folder' => NULL,
                'add_line_breaks'      => TRUE
            ])."</div>\n";
            $footer .= "</div>\n";
        }

        $footer .= "<div class='col-xs-12 col-md-12 m-t-10'>\n";
        $footer .= "<div class='overflow-hide thumbnail m-b-15' style='height: 120px;'><img class='img-responsive center-y' style='max-height:100%;' src='".AGVF_PATH."images/ageverify.svg' alt='' /></div>";
        $footer .= openform('ageverifyform', 'post', FUSION_REQUEST, ['class'=>'text-center m-l-15']);
        $footer .= "<h1>".$locale['AGVF_016']."</h1>";
        $footer .= $agebutton;
        $footer .= closeform();
        $footer .= "</div>\n";
        $footer .= "<div class='panel-footer col-xs-12 col-md-12 m-t-10 text-center'>\n";
        $footer .= parse_text($locale['AGVF_015'], [
            'parse_smileys'        => FALSE,
            'parse_bbcode'         => FALSE,
            'default_image_folder' => NULL,
            'add_line_breaks'      => TRUE
        ]);
        $footer .= "</div>\n";
        $footer .= "</div>\n";
        $footer .= "</div>\n";
        $footer .= closemodal();

        add_to_footer($footer);
    }
}

function get_noverify($url, $time) {
    add_to_head("<script type='text/javascript'>\n
        function delayer(){ window.location = '".$url."'; }
        setTimeout('delayer()', ".$time.");
    </script>\n");
}

function set_ageVerify($duration) {
    fusion_set_cookie(COOKIE_PREFIX."ageverifycontrol", "yes", time() + $duration, COOKIE_PATH, COOKIE_DOMAIN, FALSE, TRUE);
}
